.. _phoenix_transport:

PhoenixChannelWebsocketsTransport
=================================

The PhoenixChannelWebsocketsTransport is an async transport which allows you
to execute queries and subscriptions against an `Absinthe`_ backend using the `Phoenix`_
framework `channels`_.

Reference:
:class:`gql.transport.phoenix_channel_websockets.PhoenixChannelWebsocketsTransport`

.. literalinclude:: ../code_examples/phoenix_channel_async.py

.. _Absinthe: http://absinthe-graphql.org
.. _Phoenix: https://www.phoenixframework.org
.. _channels: https://hexdocs.pm/phoenix/Phoenix.Channel.html#content
